pub struct FrameSessionMetrics { /* private fields */ }Expand description
Read-only liveness and connectivity metrics for a FrameSession.
Implementations
Sourceimpl FrameSessionMetrics
impl FrameSessionMetrics
Sourcepub fn last_loop_activity(&self) -> Option<Instant>
pub fn last_loop_activity(&self) -> Option<Instant>
Returns the last time the scheduler thread showed progress.
Sourcepub fn last_write_success(&self) -> Option<Instant>
pub fn last_write_success(&self) -> Option<Instant>
Returns the last time a backend write completed successfully.